<?php
// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Load chatbot script based on settings
function interworky_assistant_add_script() {
    $visibility = sanitize_text_field(get_option('interworky_visibility', 'all'));
    $page_paths = sanitize_text_field(get_option('interworky_page_paths', ''));
    $api_key = get_option('interworky_api_key', '');

    // Ensure API key is set
    if (empty($api_key)) {
        return;
    }

    // Set the chatbot script URL
    $scriptSrc = "https://storage.googleapis.com/multisync/interworky/production/interworky.js";

    // Get the current page path safely
    $current_path = '';

    if (!empty($_SERVER['REQUEST_URI'])) {
        $unslashed_uri = wp_unslash($_SERVER['REQUEST_URI']); // Remove slashes
        $parsed_uri = wp_parse_url($unslashed_uri, PHP_URL_PATH); // Extract only the path
        $current_path = '/' . trim(sanitize_text_field($parsed_uri), '/') . '/'; // Ensure leading & trailing slashes
    }

    // Convert user input into an array of trimmed paths (ensure paths have slashes)
    $selected_paths = array_filter(array_map(function ($path) {
        return '/' . trim(sanitize_text_field($path), '/') . '/';
    }, explode(',', $page_paths)));

    // Determine if the script should load
    $load_script = false;

    if ($visibility === 'all') {
        $load_script = true;
    } elseif ($visibility === 'include' && in_array($current_path, $selected_paths, true)) {
        $load_script = true;
    } elseif ($visibility === 'exclude' && !in_array($current_path, $selected_paths, true)) {
        $load_script = true;
    }
    
    // Enqueue chatbot script if conditions are met
    if ($load_script) {
        echo "<script src='${scriptSrc}' data-api-key='$api_key'></script>";
    }
}
add_action('wp_enqueue_scripts', 'interworky_assistant_add_script');
